Authors
=======

This file contains the list of people involved in the development of
pytest-dbfixtures along it's history.

* Paweł Wilczyński
* Tomasz Święcicki
* Tomasz Karbownicki
* Grzegorz Śliwiński
* Przemysław Spodymek
* Jonas Brunsgaard
* Donald Stufft
* Hans Duedal
* Domen Kožar
* Dwayne Litzenberger

Great thanks to `Clearcode <http://clearcode.cc>`_ for allowing releasing
pytest-dbfixtures as free software!
